HangulJosaSelectionIGa class
한글 조사: 이/가
이 클래스는 HangulJosaSelection("이", "가")로도 나타낼 수 있습니다.
print("${hangulJosa("강아지", HangulJosaSelectionIGa())} 노래를 한다."); // 강아지가 노래를 한다.
- Inheritance
-
- Object
- HangulJosaSelection
- HangulJosaSelectionIGa
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- josaNoFinalConsonant → String
-
마지막 글자가 받침이 없을 때 해당 조사를 선택합니다.
finalinherited
- josaWithFinalConsonant → String
-
마지막 글자가 받침이 있을 때 해당 조사를 선택합니다.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited